@@ -7,7 +7,7 @@
 # redistribute it and/or modify it under the same terms as Perl
 # itself.
 #
-# $Id: DBServer.pm,v 1.14 2001/05/27 11:07:17 cvs Exp $
+# $Id: DBServer.pm,v 1.8 2000/11/14 21:41:59 cvs Exp $
 
 package Replication::Recall::DBServer;
 
@@ -25,7 +25,7 @@ use Replication::Recall::Server;
 use vars qw( $VERSION $AUTOLOAD );
 use POSIX qw( :sys_wait_h :signal_h :errno_h );
 
-( $VERSION ) = '$Revision: 1.14 $' =~ /\s+([\d\.]+)/;
+( $VERSION ) = '$Revision: 1.8 $' =~ /\s+([\d\.]+)/;
 my $recovering = {};
 
 sub reaper { 
@@ -74,15 +74,14 @@ sub debug {
 }
 
 sub run {
+  package Replication::Recall::Server;
   my $self = shift;
-  my $opts = Replication::Recall::Server::new_EchoOptions();
-  my $echo = Replication::Recall::Server::new_Echo();
+  my $opts = new_EchoOptions();
+  my $echo = new_Echo();
   my $names = join(',', @{$self->{Replicas}});
-  Replication::Recall::Server::Logger_disable_debug_messages 
-    (Replication::Recall::Server::Logger_instance()) unless ($self->{Debug});
-  Replication::Recall::Server::Echo_start
-    ($echo, $names, $opts, $self) and die "Couldn't start server.\n";
-  Replication::Recall::Server::Echo_loop($echo);
+  Logger_disable_debug_messages(Logger_instance()) unless ($self->{Debug});
+  Echo_start($echo, $names, $opts, $self) and die "Couldn't start server.\n";
+  Echo_loop($echo);
 }
 
 sub read {
@@ -125,20 +124,14 @@ sub write {
     $ret{Return} = [ $self->{Handles}->{$self->{Counter}}?$self->{Counter}:undef ];
   }
   elsif ($args{Meta} =~ /^Auto/) {
-    return undef unless my $handle = $self->{Handles}->{$args{Handle}}; 
-    my $method = $args{Method};
+    my $handle = $self->{Handles}->{$args{Handle}}; my $method = $args{Method};
     my @eval = eval { $$handle{Handle}->$method(@{$args{Args}}) };
     delete $ret{Die}, @eval = eval { $$handle{Handle}->func(@{$args{Args}}, $method) }
       if $ret{Die} =~ /Can\'t locate object method/;
     $ret{Return} = [ @eval ]; $ret{Eval} = $@ if $@;
-    if ($args{Method} eq 'DESTROY') {
-      $self->debug("Foo! $args{Handle}\n");
-      delete $self->{Handles}->{$args{Handle}};
-    }
-    else {
-      $ret{Error} = $$handle{Handle}->errstr(); $ret{Err} = $$handle{Handle}->err(); 
-      $ret{State} = $$handle{Handle}->state(); 
-    }
+    $ret{Error} = $$handle{Handle}->errstr(); $ret{Err} = $$handle{Handle}->err(); 
+    $ret{State} = $$handle{Handle}->state(); 
+    delete $self->{Handles}->{$args{Handle}} if $args{Method} eq 'DESTROY';
   }
   $self->writelocked(0);
   my $ret = defined &Data::Dumper::Dumpxs?Data::Dumper::DumperX(\%ret):Dumper(\%ret);
@@ -264,43 +257,29 @@ sub AUTOLOAD {
 END {
 }
 
-"True Value";
-__END__
+=pod
 
 =head1 NAME 
 
 Replication::Recall::DBServer - Database replication server.
 
-=head1 VERSION
-
- $Revision: 1.14 $
- $Date: 2001/05/27 11:07:17 $
-
 =head1 SYNOPSIS
 
   use Replication::Recall::DBServer;
-
   my $port = 8500;
 
-  my $server = new Replication::Recall::DBServer
-    ( Replicas    => ["192.168.1.1:$port",
-		      "192.168.1.2:$port",
-                      "192.168.1.3:$port"],
-
+  my $server = new Replication::Recall::DBServer 
+    ( Replicas    => ["192.168.1.1:$port","192.168.1.2:$port","192.168.1.3:$port"], 
       DSN         => 'DBI:mysql:database=replica1;host=localhost;port=',
-
-      StopServer  => sub { system ('mysqladmin','shutdown') },
-
-      StartServer => sub { system ('start-stop-daemon', 
-	                           '--start', '-b', '-x', 
-                                   '/usr/bin/safe_mysqld') },
-
-      SyncPath    => '/var/lib/mysql/replica1/',
+      StopServer  => sub { system ("mysqladmin shutdown") },
+      StartServer => sub { system ("start-stop-daemon --start -b -x /usr/bin/safe_mysqld") },
+      SyncPath    => '/var/lib/mysql/replica1/', 
       SyncCmd     => 'ssh -l mysql',
       Debug       => 1
     );
 
   unless (fork) { $server->run() }
+
   wait();
 
 =head1 DESCRIPTION
@@ -310,7 +289,7 @@ by Eric Newton, to enable the setup of replicated database servers.
 
 Recall is based on a data replication algorithm developed at DEC's SRC
 for the Echo filesystem. It implements a fast protocol with low
-network overhead and guranteed fault tolerance as long as n of 2n-1
+network overhead and guranteed fault tolerance as long as n of 2n+1
 replica nodes are up.
 
 The Replication::Recall::DBServer module provides the functionality
@@ -408,10 +387,20 @@ Run the server. Doesn't return if all goes well.
 
 =back
 
+=head1 BUGS
+
+=over 2
+
+=item * 
+
+There must be loads. Let me know if you find some.
+
+=back
+
 =head1 AUTHOR
 
-Replication::Recall::DBServer is Copyright (c) 2000-2001 Ashish
-Gulhati <hash@netropolis.org>.  All Rights Reserved.
+DBD::Recall is Copyright (c) 2000 Ashish Gulhati
+<hash@netropolis.org>.  All Rights Reserved.
 
 =head1 ACKNOWLEDGEMENTS
 
